//
//  ViewController.swift
//  Weight
//
//  Created by Matthew Newill on 21/11/2016.
//  Copyright © 2016 DevFright.com. All rights reserved.
//

import UIKit
import HealthKit

class ViewController: UIViewController {
    
    @IBOutlet weak var lineView: LineView!
    @IBOutlet weak var weightTextField: UITextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(updateGraph(notification:)),
                                               name: NSNotification.Name(rawValue: "BodyMassDataAvailable"),
                                               object: nil)
        
        if HKHealthStore.isHealthDataAvailable() {
            // add code to use HealthKit here...
            print("Yes, HealthKit is Available")
            let healthManager = HealthManager()
            healthManager.requestPermissions()
        } else {
            print("There is a problem accessing HealthKit")
        }
    }
    
    func updateGraph(notification: Notification) {
        print(notification.object!)
        let weightArray = notification.object as! Array<HKQuantitySample>
        
        // Find the HKQuantitySample with the largest quantity and lowest quantity.
        let maxSample = weightArray.max { a, b in a.quantity.doubleValue(for: HKUnit.init(from: .pound)) < b.quantity.doubleValue(for: HKUnit.init(from: .pound)) }
        let lowSample = weightArray.min { a, b in a.quantity.doubleValue(for: HKUnit.init(from: .pound)) < b.quantity.doubleValue(for: HKUnit.init(from: .pound)) }
        
        // Set the upper and lower values rounding up and down.
        lineView.upperValue = CGFloat.init(5 * ceil((maxSample?.quantity.doubleValue(for: HKUnit.init(from: .pound)))!/5))
        lineView.lowerValue = CGFloat.init(5 * floor((lowSample?.quantity.doubleValue(for: HKUnit.init(from: .pound)))!/5))
        
        for weightElement : HKQuantitySample in weightArray {
            if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -6*24*60*60)) {
                lineView.point0 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -5*24*60*60)) {
                lineView.point1 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -4*24*60*60)) {
                lineView.point2 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -3*24*60*60)) {
                lineView.point3 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -2*24*60*60)) {
                lineView.point4 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date.init(timeIntervalSinceNow: -1*24*60*60)) {
                lineView.point5 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            } else if Calendar.current.isDate(weightElement.startDate, inSameDayAs: Date()) {
                lineView.point6 = CGFloat.init(weightElement.quantity.doubleValue(for: HKUnit.init(from: .pound)))
            }
            
        }
        
        lineView.setNeedsDisplay()
    }
    
    @IBAction func submitWeight(_ sender: UIButton) {
        let healthManager = HealthManager()
        let weight = (weightTextField.text! as NSString).doubleValue
        healthManager.submitWeight(weight: weight, forDate: Date())
    }

    @IBAction func refreshGraph(_ sender: UIButton) {
        let healthManager = HealthManager()
        healthManager.fetchWeightData()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

}
